==> use-hashcode-0.1.0.tgz: package/src/index.tsx <==
import { useEffect, useRef, useState } from 'react'
import CryptoJs from 'crypto-js'
import encHex from 'crypto-js/enc-hex'

export interface Encoder {
  stringify (wordArray: WordArray): string;

  parse (str: string): WordArray;
}

export interface WordArray {
  words: number[];
  sigBytes: number;

  toString (encoder?: Encoder): string;

  concat (wordArray: WordArray): this;

  clamp (): void;

  clone (): WordArray;
}

export interface Hasher {
  reset (): void;

  update (messageUpdate: WordArray | string): this;

  finalize (messageUpdate?: WordArray | string): WordArray;
}

export interface IUseHashFileReturn {
  isHashLoading: boolean,
  isHashError: boolean,
  sha256: string | null,
  sha1: string | null,
  md5: string | null,
  timeSpend: number | null,
}

/**
 * hash文件
 * @param file 需要计算的文件
 * @param hashAlgo hash 计算的算法 'md5' |'sha1'| 'sha256'  默认为 sha256
 * @param chunkSizeCustom   分块大小 默认为 10M
 * @return IUseHashFileReturn
 */
const useHashCode = (file: File | null, hashAlgo?: 'md5' | 'sha1' | 'sha256', chunkSizeCustom?: number): IUseHashFileReturn => {
  const startTimeRef = useRef<number | null>(null)
  const [isHashLoading, setIsHashLoading] = useState<boolean>(true)
  const [isHashError, setIsHashError] = useState<boolean>(false)
  const [sha256, setSha256] = useState<string | null>(null)
  const [sha1, setSha1] = useState<string | null>(null)
  const [md5, setMd5] = useState<string | null>(null)
  const [timeSpend, setTimeSpend] = useState<number | null>(null)

  useEffect(() => {
    if (!file) return
    /* 记录开始计算时间 */
    startTimeRef.current = Date.now()

    const hashFileInternal = (file: File, alog: Hasher) => {
      let chunkSize = 1024 * 1024 * 10
      /* 自定义分块大小 */
      if (chunkSizeCustom) {
        chunkSize = chunkSizeCustom
      }
      let promise = Promise.resolve()
      for (let index = 0; index < file.size; index += chunkSize) {
        promise = promise.then(() => hashBlob(file.slice(index, index + chunkSize)))
      }

      /* arraybuffer 转 word array */
      function arrayBufferToWordArray (ab: ArrayBuffer) {
        const i8a = new Uint8Array(ab)
        const a = []
        for (let i = 0; i < i8a.length; i += 4) {
          a.push(i8a[i] << 24 | i8a[i + 1] << 16 | i8a[i + 2] << 8 | i8a[i + 3])
        }
        return CryptoJs.lib.WordArray.create(a, i8a.length)
      }

      /* hash blob */
      const hashBlob = (blob: Blob) => {
        return new Promise<void>((resolve) => {
          const reader = new FileReader()
          reader.onload = ({ target }) => {
            if (!target!.result) return
            if (typeof target!.result === 'string') return
            const wordArray = arrayBufferToWordArray(target!.result)
            // 增量更新计算结果
            alog.update(wordArray)
            resolve()
          }
          reader.readAsArrayBuffer(blob)
        })
      }

      return promise.then(() => encHex.stringify(alog.finalize()))
    }

    const hashFileSha256 = () => {
      hashFileInternal(file, CryptoJs.algo.SHA256.create()).then((sha256) => {
        setSha256(sha256)
        if (startTimeRef.current) {
          const t = Date.now() - startTimeRef.current
          setTimeSpend(t)
        }
      }).catch(() => {
        setIsHashError(true)
        setIsHashLoading(false)
      })
    }

    switch (hashAlgo) {
      case 'md5':
        hashFileInternal(file, CryptoJs.algo.MD5.create()).then((md5) => {
          setMd5(md5)
          if (startTimeRef.current) {
            const t = Date.now() - startTimeRef.current
            setTimeSpend(t)
          }
        }).catch(() => {
          setIsHashError(true)
          setIsHashLoading(false)
        })
        break
      case 'sha1':
        hashFileInternal(file, CryptoJs.algo.SHA1.create()).then((sha1) => {
          setSha1(sha1)
          if (startTimeRef.current) {
            const t = Date.now() - startTimeRef.current
            setTimeSpend(t)
          }
        }).catch(() => {
          setIsHashError(true)
          setIsHashLoading(false)
        })
        break
      case 'sha256':
        hashFileSha256()
        break
      default:
        hashFileSha256()
    }
  }, [chunkSizeCustom, file, hashAlgo])

  return {
    isHashLoading,
    isHashError,
    sha256,
    sha1,
    md5,
    timeSpend,
  }
}

export default useHashCode

==> use-hashcode-0.1.1.tgz: package/src/index.tsx <==
import { useEffect, useRef, useState } from 'react'
import CryptoJs from 'crypto-js'
import encHex from 'crypto-js/enc-hex'

export interface Encoder {
  stringify (wordArray: WordArray): string;

  parse (str: string): WordArray;
}

export interface WordArray {
  words: number[];
  sigBytes: number;

  toString (encoder?: Encoder): string;

  concat (wordArray: WordArray): this;

  clamp (): void;

  clone (): WordArray;
}

export interface Hasher {
  reset (): void;

  update (messageUpdate: WordArray | string): this;

  finalize (messageUpdate?: WordArray | string): WordArray;
}

export interface IUseHashFileReturn {
  isHashLoading: boolean, // is hash loading
  isHashError: boolean, // is hash error
  sha256: string | null, // hashcode -sha256
  sha1: string | null, // hashcode sha1
  md5: string | null, // hashcode md5
  timeSpend: number | null, // time spend
}

/**
 * hash file
 * @param file the file need to hash
 * @param hashAlgo hash algorithm 'md5' |'sha1'| 'sha256'  default:sha256
 * @param chunkSizeCustom   chunk size default:10M
 * @return IUseHashFileReturn
 */
export const useHashFileCode = (file: File | null, hashAlgo?: 'md5' | 'sha1' | 'sha256', chunkSizeCustom?: number): IUseHashFileReturn => {
  const startTimeRef = useRef<number | null>(null)
  const [isHashLoading, setIsHashLoading] = useState<boolean>(true)
  const [isHashError, setIsHashError] = useState<boolean>(false)
  const [sha256, setSha256] = useState<string | null>(null)
  const [sha1, setSha1] = useState<string | null>(null)
  const [md5, setMd5] = useState<string | null>(null)
  const [timeSpend, setTimeSpend] = useState<number | null>(null)

  useEffect(() => {
    if (!file) return
    /* record start time */
    startTimeRef.current = Date.now()

    const hashFileInternal = (file: File, alog: Hasher) => {
      let chunkSize = 1024 * 1024 * 10
      /* custom chunk size */
      if (chunkSizeCustom) {
        chunkSize = chunkSizeCustom
      }
      let promise = Promise.resolve()
      for (let index = 0; index < file.size; index += chunkSize) {
        promise = promise.then(() => hashBlob(file.slice(index, index + chunkSize)))
      }

      /* arraybuffer to word array */
      function arrayBufferToWordArray (ab: ArrayBuffer) {
        const i8a = new Uint8Array(ab)
        const a = []
        for (let i = 0; i < i8a.length; i += 4) {
          a.push(i8a[i] << 24 | i8a[i + 1] << 16 | i8a[i + 2] << 8 | i8a[i + 3])
        }
        return CryptoJs.lib.WordArray.create(a, i8a.length)
      }

      /* hash blob */
      const hashBlob = (blob: Blob) => {
        return new Promise<void>((resolve) => {
          const reader = new FileReader()
          reader.onload = ({ target }) => {
            if (!target!.result) return
            if (typeof target!.result === 'string') return
            const wordArray = arrayBufferToWordArray(target!.result)
            // update hash
            alog.update(wordArray)
            resolve()
          }
          reader.readAsArrayBuffer(blob)
        })
      }

      return promise.then(() => encHex.stringify(alog.finalize()))
    }

    const hashFileSha256 = () => {
      hashFileInternal(file, CryptoJs.algo.SHA256.create()).then((sha256) => {
        setSha256(sha256)
        if (startTimeRef.current) {
          const t = Date.now() - startTimeRef.current
          setTimeSpend(t)
        }
      }).catch(() => {
        setIsHashError(true)
        setIsHashLoading(false)
      })
    }

    /* chose algo */
    switch (hashAlgo) {
      case 'md5':
        hashFileInternal(file, CryptoJs.algo.MD5.create()).then((md5) => {
          setMd5(md5)
          if (startTimeRef.current) {
            const t = Date.now() - startTimeRef.current
            setTimeSpend(t)
          }
        }).catch(() => {
          setIsHashError(true)
          setIsHashLoading(false)
        })
        break
      case 'sha1':
        hashFileInternal(file, CryptoJs.algo.SHA1.create()).then((sha1) => {
          setSha1(sha1)
          if (startTimeRef.current) {
            const t = Date.now() - startTimeRef.current
            setTimeSpend(t)
          }
        }).catch(() => {
          setIsHashError(true)
          setIsHashLoading(false)
        })
        break
      case 'sha256':
        hashFileSha256()
        break
      default:
        hashFileSha256()
    }
  }, [chunkSizeCustom, file, hashAlgo])

  return {
    isHashLoading,
    isHashError,
    sha256,
    sha1,
    md5,
    timeSpend,
  }
}
